@@ -20,6 +20,16 @@
 #define __PANEL_PRIVATE_H__
 
 #include <gtk/gtk.h>
+#ifdef GDK_WINDOWING_X11
+#include <gdk/gdkx.h>
+#else
+#define GDK_IS_X11_DISPLAY(display) FALSE
+#endif
+#ifdef GDK_WINDOWING_WAYLAND
+#include <gdk/gdkwayland.h>
+#else
+#define GDK_IS_WAYLAND_DISPLAY(display) FALSE
+#endif
 
 /* support macros for debugging (improved macro for better position indication) */
 /*#ifndef NDEBUG*/
@@ -75,9 +85,6 @@
 #define TRANSPOSE_AREA(area) G_STMT_START { SWAP_INTEGER (area.width, area.height); \
                                             SWAP_INTEGER (area.x, area.y); } G_STMT_END
 
-/* to avoid exo for gtk3 testing */
-#define panel_str_is_empty(string) ((string) == NULL || *(string) == '\0')
-
 /* quick GList and GSList counting without traversing */
 #define LIST_HAS_ONE_ENTRY(l)           ((l) != NULL && (l)->next == NULL)
 #define LIST_HAS_ONE_OR_NO_ENTRIES(l)   ((l) == NULL || (l)->next == NULL)
@@ -141,22 +148,4 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
-#ifdef WNCK_TYPE_SCREEN
-static inline WnckScreen *
-panel_wnck_screen_get (int index)
-{
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-  return wnck_screen_get (index);
-G_GNUC_END_IGNORE_DEPRECATIONS
-}
-
-static inline WnckScreen *
-panel_wnck_screen_get_default (void)
-{
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-  return wnck_screen_get_default ();
-G_GNUC_END_IGNORE_DEPRECATIONS
-}
-#endif
-
 #endif /* !__PANEL_PRIVATE_H__ */
