@@ -109,11 +109,6 @@ enum
   PROP_ITEMS_CHANGED
 };
 
-struct _PanelApplicationClass
-{
-  GObjectClass __parent__;
-};
-
 struct _PanelApplication
 {
   GObject  __parent__;
@@ -185,7 +180,7 @@ static const GtkTargetEntry drop_targets[] =
 
 
 
-G_DEFINE_TYPE (PanelApplication, panel_application, G_TYPE_OBJECT)
+G_DEFINE_FINAL_TYPE (PanelApplication, panel_application, G_TYPE_OBJECT)
 
 
 
@@ -239,7 +234,7 @@ panel_application_init (PanelApplication *application)
   application->factory = panel_module_factory_get ();
 
   /* start the autosave timer for plugins */
-  application->autosave_timer_id = g_timeout_add_seconds (60 * 10,
+  application->autosave_timer_id = g_timeout_add_seconds (AUTOSAVE_INTERVAL,
       panel_application_autosave_timer, application);
 
   /* warn the user about restricted features on Wayland */
@@ -345,7 +340,7 @@ panel_application_xfconf_window_bindings (PanelApplication *application,
     { "icon-size", G_TYPE_UINT },
     { "output-name", G_TYPE_STRING },
     { "position", G_TYPE_STRING },
-    { "disable-struts", G_TYPE_BOOLEAN },
+    { "enable-struts", G_TYPE_BOOLEAN },
     { NULL }
   };
   const PanelProperty  global_properties[] =
@@ -353,14 +348,26 @@ panel_application_xfconf_window_bindings (PanelApplication *application,
     { "dark-mode", G_TYPE_BOOLEAN },
     { NULL }
   };
+  const PanelProperty  old_properties[] =
+  {
+    { "autohide", G_TYPE_BOOLEAN },
+    { "disable-struts", G_TYPE_BOOLEAN },
+    { NULL }
+  };
+  const PanelProperty  new_properties[] =
+  {
+    { "autohide-behavior", G_TYPE_UINT },
+    { "enable-struts", G_TYPE_BOOLEAN },
+    { NULL }
+  };
 
   panel_return_if_fail (XFCONF_IS_CHANNEL (application->xfconf));
 
   /* create the property base */
   property_base = g_strdup_printf (PANELS_PROPERTY_BASE, panel_window_get_id (window));
 
-  /* migrate old autohide property */
-  panel_window_migrate_autohide_property (window, application->xfconf, property_base);
+  /* migrate old properties */
+  panel_window_migrate_old_properties (window, application->xfconf, property_base, old_properties, new_properties);
 
   /* bind all the properties */
   panel_properties_bind (application->xfconf, G_OBJECT (window),
