@@ -49,6 +49,10 @@
 #define MARCHING_ANTS_DOTTED  "marching-ants-dotted"
 
 
+
+#define get_instance_private(instance) ((PanelBaseWindowPrivate *) \
+  panel_base_window_get_instance_private (PANEL_BASE_WINDOW (instance)))
+
 static void     panel_base_window_get_property                (GObject              *object,
                                                                guint                 prop_id,
                                                                GValue               *value,
@@ -97,16 +101,25 @@ enum
   PROP_BACKGROUND_IMAGE
 };
 
-struct _PanelBaseWindowPrivate
+typedef struct _PanelBaseWindowPrivate
 {
   PanelBorders     borders;
 
+  /* transparency settings */
+  guint            is_composited : 1;
+  gdouble          enter_opacity;
+  gdouble          leave_opacity;
+  gboolean         opacity_is_enter;
+
   /* background css style provider */
   GtkCssProvider  *css_provider;
+  PanelBgStyle     background_style;
+  GdkRGBA         *background_rgba;
+  gchar           *background_image;
 
   /* active window timeout id */
   guint            active_timeout_id;
-};
+} PanelBaseWindowPrivate;
 
 
 
@@ -193,22 +206,21 @@ panel_base_window_class_init (PanelBaseWindowClass *klass)
 static void
 panel_base_window_init (PanelBaseWindow *window)
 {
+  PanelBaseWindowPrivate *priv = get_instance_private (window);
   GtkStyleContext *context;
-  GdkScreen       *screen;
+  GdkScreen *screen;
 
-  window->priv = panel_base_window_get_instance_private (window);
+  priv->is_composited = FALSE;
+  priv->background_style = PANEL_BG_STYLE_NONE;
+  priv->background_image = NULL;
+  priv->background_rgba = NULL;
+  priv->enter_opacity = 1.00;
+  priv->leave_opacity = 1.00;
+  priv->opacity_is_enter = FALSE;
 
-  window->is_composited = FALSE;
-  window->background_style = PANEL_BG_STYLE_NONE;
-  window->background_image = NULL;
-  window->background_rgba = NULL;
-  window->enter_opacity = 1.00;
-  window->leave_opacity = 1.00;
-  window->opacity_is_enter = FALSE;
-
-  window->priv->css_provider = gtk_css_provider_new ();
-  window->priv->borders = PANEL_BORDER_NONE;
-  window->priv->active_timeout_id = 0;
+  priv->css_provider = gtk_css_provider_new ();
+  priv->borders = PANEL_BORDER_NONE;
+  priv->active_timeout_id = 0;
 
   screen = gtk_widget_get_screen (GTK_WIDGET (window));
   g_signal_connect_object (G_OBJECT (screen), "composited-changed",
@@ -236,27 +248,27 @@ panel_base_window_get_property (GObject    *object,
                                 GParamSpec *pspec)
 {
   PanelBaseWindow         *window = PANEL_BASE_WINDOW (object);
-  PanelBaseWindowPrivate  *priv = window->priv;
+  PanelBaseWindowPrivate  *priv = get_instance_private (window);
   GdkRGBA                 *rgba;
   GtkStyleContext         *ctx;
 
   switch (prop_id)
     {
     case PROP_ENTER_OPACITY:
-      g_value_set_uint (value, rint (window->enter_opacity * 100.00));
+      g_value_set_uint (value, rint (priv->enter_opacity * 100.00));
       break;
 
     case PROP_LEAVE_OPACITY:
-      g_value_set_uint (value, rint (window->leave_opacity * 100.00));
+      g_value_set_uint (value, rint (priv->leave_opacity * 100.00));
       break;
 
     case PROP_BACKGROUND_STYLE:
-      g_value_set_uint (value, window->background_style);
+      g_value_set_uint (value, priv->background_style);
       break;
 
     case PROP_BACKGROUND_RGBA:
-      if (window->background_rgba != NULL)
-        g_value_set_boxed (value, window->background_rgba);
+      if (priv->background_rgba != NULL)
+        g_value_set_boxed (value, priv->background_rgba);
       else
         {
           ctx = gtk_widget_get_style_context (GTK_WIDGET (window));
@@ -269,7 +281,7 @@ panel_base_window_get_property (GObject    *object,
       break;
 
     case PROP_BACKGROUND_IMAGE:
-      g_value_set_string (value, window->background_image);
+      g_value_set_string (value, priv->background_image);
       break;
 
     case PROP_BORDERS:
@@ -281,7 +293,7 @@ panel_base_window_get_property (GObject    *object,
       break;
 
     case PROP_COMPOSITED:
-      g_value_set_boolean (value, window->is_composited);
+      g_value_set_boolean (value, priv->is_composited);
       break;
 
     default:
@@ -299,21 +311,22 @@ panel_base_window_set_property (GObject      *object,
                                 GParamSpec   *pspec)
 {
   PanelBaseWindow        *window = PANEL_BASE_WINDOW (object);
-  PanelBaseWindowPrivate *priv = window->priv;
+  PanelBaseWindowPrivate *priv = get_instance_private (window);
   PanelBgStyle            bg_style;
   GFile                  *file;
   gdouble                 opacity;
+  const gchar            *str;
 
   switch (prop_id)
     {
     case PROP_ENTER_OPACITY:
       opacity = g_value_get_uint (value) / 100.00;
-      if (opacity != window->enter_opacity)
+      if (opacity != priv->enter_opacity)
         {
-          window->enter_opacity = opacity;
-          if (window->is_composited && window->opacity_is_enter)
+          priv->enter_opacity = opacity;
+          if (priv->is_composited && priv->opacity_is_enter)
             {
-              gtk_widget_set_opacity (GTK_WIDGET (window), window->enter_opacity);
+              gtk_widget_set_opacity (GTK_WIDGET (window), priv->enter_opacity);
               panel_base_window_set_plugin_data (window, panel_base_window_set_plugin_enter_opacity);
             }
         }
@@ -321,12 +334,12 @@ panel_base_window_set_property (GObject      *object,
 
     case PROP_LEAVE_OPACITY:
       opacity = g_value_get_uint (value) / 100.00;
-      if (opacity != window->leave_opacity)
+      if (opacity != priv->leave_opacity)
         {
-          window->leave_opacity = opacity;
-          if (window->is_composited && ! window->opacity_is_enter)
+          priv->leave_opacity = opacity;
+          if (priv->is_composited && ! priv->opacity_is_enter)
             {
-              gtk_widget_set_opacity (GTK_WIDGET (window), window->leave_opacity);
+              gtk_widget_set_opacity (GTK_WIDGET (window), priv->leave_opacity);
               panel_base_window_set_plugin_data (window, panel_base_window_set_plugin_leave_opacity);
             }
         }
@@ -334,26 +347,26 @@ panel_base_window_set_property (GObject      *object,
 
     case PROP_BACKGROUND_STYLE:
       bg_style = g_value_get_uint (value);
-      if (window->background_style != bg_style)
+      if (priv->background_style != bg_style)
         {
-          window->background_style = bg_style;
+          priv->background_style = bg_style;
 
           /* send information to external plugins */
-          if (window->background_style == PANEL_BG_STYLE_IMAGE
-              && window->background_image != NULL)
+          if (priv->background_style == PANEL_BG_STYLE_IMAGE
+              && priv->background_image != NULL)
             {
               panel_base_window_set_background_image_css (window);
               panel_base_window_set_plugin_data (window,
                   panel_base_window_set_plugin_background_image);
             }
-          else if (window->background_style == PANEL_BG_STYLE_NONE)
+          else if (priv->background_style == PANEL_BG_STYLE_NONE)
             {
               panel_base_window_reset_background_css (window);
               panel_base_window_set_plugin_data (window,
                   panel_base_window_set_plugin_background_color);
             }
-          else if (window->background_style == PANEL_BG_STYLE_COLOR
-                   && window->background_rgba != NULL)
+          else if (priv->background_style == PANEL_BG_STYLE_COLOR
+                   && priv->background_rgba != NULL)
             {
               panel_base_window_set_background_color_css (window);
               panel_base_window_set_plugin_data (window,
@@ -366,11 +379,11 @@ panel_base_window_set_property (GObject      *object,
       break;
 
     case PROP_BACKGROUND_RGBA:
-      if (window->background_rgba != NULL)
-        gdk_rgba_free (window->background_rgba);
-      window->background_rgba = g_value_dup_boxed (value);
+      if (priv->background_rgba != NULL)
+        gdk_rgba_free (priv->background_rgba);
+      priv->background_rgba = g_value_dup_boxed (value);
 
-      if (window->background_style == PANEL_BG_STYLE_COLOR)
+      if (priv->background_style == PANEL_BG_STYLE_COLOR)
         {
           panel_base_window_set_background_color_css (window);
           panel_base_window_set_plugin_data (window,
@@ -379,13 +392,19 @@ panel_base_window_set_property (GObject      *object,
       break;
 
     case PROP_BACKGROUND_IMAGE:
-      /* store new uri, built and escaped through a GFile */
-      g_free (window->background_image);
-      file = g_file_new_for_commandline_arg (g_value_get_string (value));
-      window->background_image = g_file_get_uri (file);
-      g_object_unref (file);
+      g_free (priv->background_image);
+      str = g_value_get_string (value);
+      if (str != NULL)
+        {
+          /* store new uri, built and escaped through a GFile */
+          file = g_file_new_for_commandline_arg (str);
+          priv->background_image = g_file_get_uri (file);
+          g_object_unref (file);
+        }
+      else
+        priv->background_image = NULL;
 
-      if (window->background_style == PANEL_BG_STYLE_IMAGE)
+      if (priv->background_style == PANEL_BG_STYLE_IMAGE)
         {
           panel_base_window_set_background_image_css (window);
           panel_base_window_set_plugin_data (window,
@@ -432,17 +451,17 @@ panel_base_window_set_property (GObject      *object,
 static void
 panel_base_window_finalize (GObject *object)
 {
-  PanelBaseWindow *window = PANEL_BASE_WINDOW (object);
+  PanelBaseWindowPrivate *priv = get_instance_private (object);
 
   /* stop running marching ants timeout */
-  if (window->priv->active_timeout_id != 0)
-    g_source_remove (window->priv->active_timeout_id);
+  if (priv->active_timeout_id != 0)
+    g_source_remove (priv->active_timeout_id);
 
   /* release bg colors data */
-  g_free (window->background_image);
-  if (window->background_rgba != NULL)
-    gdk_rgba_free (window->background_rgba);
-  g_object_unref (window->priv->css_provider);
+  g_free (priv->background_image);
+  if (priv->background_rgba != NULL)
+    gdk_rgba_free (priv->background_rgba);
+  g_object_unref (priv->css_provider);
 
   (*G_OBJECT_CLASS (panel_base_window_parent_class)->finalize) (object);
 }
@@ -452,23 +471,25 @@ panel_base_window_finalize (GObject *object)
 static void
 panel_base_window_screen_changed (GtkWidget *widget, GdkScreen *previous_screen)
 {
-  PanelBaseWindow *window = PANEL_BASE_WINDOW (widget);
-  GdkVisual       *visual;
-  GdkScreen       *screen;
+  PanelBaseWindowPrivate *priv = get_instance_private (widget);
+  GdkVisual *visual;
+  GdkScreen *screen;
 
   if (GTK_WIDGET_CLASS (panel_base_window_parent_class)->screen_changed != NULL)
     GTK_WIDGET_CLASS (panel_base_window_parent_class)->screen_changed (widget, previous_screen);
 
   /* set the rgba colormap if supported by the screen */
-  screen = gtk_window_get_screen (GTK_WINDOW (window));
+  screen = gtk_window_get_screen (GTK_WINDOW (widget));
   visual = gdk_screen_get_rgba_visual (screen);
-  window->is_composited = gdk_screen_is_composited (screen);
-  if (visual != NULL && window->is_composited)
-    gtk_widget_set_visual (widget, visual);
+  if (visual != NULL)
+    {
+      gtk_widget_set_visual (widget, visual);
+      priv->is_composited = gdk_screen_is_composited (screen);
+    }
 
    panel_debug (PANEL_DEBUG_BASE_WINDOW,
-               "%p: rgba visual=%p, compositing=%s", window,
-               visual, PANEL_DEBUG_BOOL (window->is_composited));
+               "%p: rgba visual=%p, compositing=%s", widget,
+               visual, PANEL_DEBUG_BOOL (priv->is_composited));
 }
 
 
@@ -477,36 +498,37 @@ static void
 panel_base_window_composited_changed (GdkScreen *screen,
                                       GtkWidget *widget)
 {
+  PanelBaseWindowPrivate *priv = get_instance_private (widget);
   PanelBaseWindow *window = PANEL_BASE_WINDOW (widget);
-  gboolean         was_composited = window->is_composited;
+  gboolean         was_composited = priv->is_composited;
   GdkWindow       *gdkwindow;
   GtkAllocation    allocation;
 
   /* set new compositing state */
-  window->is_composited = gdk_screen_is_composited (screen);
+  priv->is_composited = gdk_screen_is_composited (screen);
 
-  if (window->is_composited == was_composited)
+  if (priv->is_composited == was_composited)
     return;
 
-  if (window->is_composited)
+  if (priv->is_composited)
     {
-      gtk_widget_set_opacity (GTK_WIDGET (widget), window->leave_opacity);
+      gtk_widget_set_opacity (GTK_WIDGET (widget), priv->leave_opacity);
       panel_base_window_set_plugin_data (window,
                                          panel_base_window_set_plugin_leave_opacity);
     }
   else
     {
       /* make sure to always disable the leave opacity without compositing */
-      window->opacity_is_enter = FALSE;
+      priv->opacity_is_enter = FALSE;
       gtk_widget_set_opacity (GTK_WIDGET (widget), 1.0);
       panel_base_window_set_plugin_data (window,
                                          panel_base_window_set_plugin_leave_opacity);
     }
   panel_debug (PANEL_DEBUG_BASE_WINDOW,
                "%p: compositing=%s", window,
-               PANEL_DEBUG_BOOL (window->is_composited));
+               PANEL_DEBUG_BOOL (priv->is_composited));
 
-  if (window->is_composited != was_composited)
+  if (priv->is_composited != was_composited)
     g_object_notify (G_OBJECT (widget), "composited");
 
   /* make sure the entire window is redrawn */
@@ -556,11 +578,11 @@ panel_base_window_active_timeout (gpointer user_data)
 static void
 panel_base_window_active_timeout_destroyed (gpointer user_data)
 {
-  PanelBaseWindow        *window = PANEL_BASE_WINDOW (user_data);
-  GtkStyleContext        *context;
+  PanelBaseWindowPrivate *priv = get_instance_private (user_data);
+  GtkStyleContext *context;
 
-  window->priv->active_timeout_id = 0;
-  context = gtk_widget_get_style_context (GTK_WIDGET (window));
+  priv->active_timeout_id = 0;
+  context = gtk_widget_get_style_context (GTK_WIDGET (user_data));
 
   /* Stop the marching ants */
   if (gtk_style_context_has_class (context, MARCHING_ANTS_DASHED))
@@ -574,11 +596,12 @@ panel_base_window_active_timeout_destroyed (gpointer user_data)
 static void
 panel_base_window_set_background_color_css (PanelBaseWindow *window)
 {
+  PanelBaseWindowPrivate *priv = get_instance_private (window);
   gchar *css_string, *str;
 
-  panel_return_if_fail (window->background_rgba != NULL);
+  panel_return_if_fail (priv->background_rgba != NULL);
 
-  str = gdk_rgba_to_string (window->background_rgba);
+  str = gdk_rgba_to_string (priv->background_rgba);
   css_string = g_strdup_printf (".xfce4-panel.background { background: %s; "
                                                           "border-color: transparent; } %s",
                                 str, PANEL_BASE_CSS);
@@ -594,13 +617,14 @@ panel_base_window_set_background_color_css (PanelBaseWindow *window)
 static void
 panel_base_window_set_background_image_css (PanelBaseWindow *window)
 {
+  PanelBaseWindowPrivate *priv = get_instance_private (window);
   gchar *css_string;
 
-  panel_return_if_fail (window->background_image != NULL);
+  panel_return_if_fail (priv->background_image != NULL);
 
   css_string = g_strdup_printf (".xfce4-panel.background { background: url(\"%s\");"
                                                           "border-color: transparent; } %s",
-                                window->background_image, PANEL_BASE_CSS);
+                                priv->background_image, PANEL_BASE_CSS);
 
   panel_base_window_set_background_css (window, css_string);
 
@@ -613,15 +637,16 @@ static void
 panel_base_window_set_background_css (PanelBaseWindow *window,
                                       const gchar *css_string)
 {
+  PanelBaseWindowPrivate *priv = get_instance_private (window);
   GtkStyleContext *context;
 
   context = gtk_widget_get_style_context (GTK_WIDGET (window));
 
   /* Reset the css style provider */
-  gtk_style_context_remove_provider (context, GTK_STYLE_PROVIDER (window->priv->css_provider));
-  gtk_css_provider_load_from_data (window->priv->css_provider, css_string, -1, NULL);
+  gtk_style_context_remove_provider (context, GTK_STYLE_PROVIDER (priv->css_provider));
+  gtk_css_provider_load_from_data (priv->css_provider, css_string, -1, NULL);
   gtk_style_context_add_provider (context,
-                                  GTK_STYLE_PROVIDER (window->priv->css_provider),
+                                  GTK_STYLE_PROVIDER (priv->css_provider),
                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 }
 
@@ -630,7 +655,7 @@ panel_base_window_set_background_css (PanelBaseWindow *window,
 void
 panel_base_window_reset_background_css (PanelBaseWindow *window)
 {
-  PanelBaseWindowPrivate  *priv = window->priv;
+  PanelBaseWindowPrivate  *priv = get_instance_private (window);
   GtkStyleContext         *context;
   GdkRGBA                 *background_rgba;
   gchar                   *border_side = NULL;
@@ -639,7 +664,7 @@ panel_base_window_reset_background_css (PanelBaseWindow *window)
 
   context = gtk_widget_get_style_context (GTK_WIDGET (window));
   gtk_style_context_remove_provider (context,
-                                     GTK_STYLE_PROVIDER (window->priv->css_provider));
+                                     GTK_STYLE_PROVIDER (priv->css_provider));
   /* Get the background color of the panel to draw the border */
   gtk_style_context_get (context, GTK_STATE_FLAG_NORMAL,
                          GTK_STYLE_PROPERTY_BACKGROUND_COLOR,
@@ -660,16 +685,16 @@ panel_base_window_reset_background_css (PanelBaseWindow *window)
       color_text = gdk_rgba_to_string (background_rgba);
       base_css = g_strdup_printf ("%s .xfce4-panel.background { border-style: %s; border-width: 1px; border-color: shade(%s, 0.7); }",
                                   PANEL_BASE_CSS, border_side, color_text);
-      gtk_css_provider_load_from_data (window->priv->css_provider, base_css, -1, NULL);
+      gtk_css_provider_load_from_data (priv->css_provider, base_css, -1, NULL);
       g_free (base_css);
       g_free (color_text);
       g_free (border_side);
     }
   else
-    gtk_css_provider_load_from_data (window->priv->css_provider, PANEL_BASE_CSS, -1, NULL);
+    gtk_css_provider_load_from_data (priv->css_provider, PANEL_BASE_CSS, -1, NULL);
 
   gtk_style_context_add_provider (context,
-                                  GTK_STYLE_PROVIDER (window->priv->css_provider),
+                                  GTK_STYLE_PROVIDER (priv->css_provider),
                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   gdk_rgba_free (background_rgba);
 }
@@ -680,7 +705,7 @@ void
 panel_base_window_orientation_changed (PanelBaseWindow *window,
                                        gint             mode)
 {
-  GtkStyleContext         *context = gtk_widget_get_style_context (GTK_WIDGET (window));
+  GtkStyleContext *context = gtk_widget_get_style_context (GTK_WIDGET (window));
 
   /* Reset all orientation-related style-classes */
   if (gtk_style_context_has_class (context, "horizontal"))
@@ -718,9 +743,8 @@ static void
 panel_base_window_set_plugin_enter_opacity (GtkWidget *widget,
                                             gpointer   user_data)
 {
-  PanelBaseWindow *window = PANEL_BASE_WINDOW (user_data);
-
-  panel_base_window_set_plugin_opacity (widget, user_data, window->enter_opacity);
+  panel_base_window_set_plugin_opacity (widget, user_data,
+                                        get_instance_private (user_data)->enter_opacity);
 }
 
 
@@ -729,10 +753,10 @@ static void
 panel_base_window_set_plugin_leave_opacity (GtkWidget *widget,
                                             gpointer   user_data)
 {
-  PanelBaseWindow *window = PANEL_BASE_WINDOW (user_data);
+  PanelBaseWindowPrivate *priv = get_instance_private (user_data);
 
-  if (window->is_composited)
-    panel_base_window_set_plugin_opacity (widget, user_data, window->leave_opacity);
+  if (priv->is_composited)
+    panel_base_window_set_plugin_opacity (widget, user_data, priv->leave_opacity);
   else
     panel_base_window_set_plugin_opacity (widget, user_data, 1.0);
 }
@@ -757,14 +781,14 @@ static void
 panel_base_window_set_plugin_background_color (GtkWidget *widget,
                                                gpointer   user_data)
 {
-  PanelBaseWindow *window = PANEL_BASE_WINDOW (user_data);
-  GdkRGBA         *color;
+  PanelBaseWindowPrivate *priv = get_instance_private (user_data);
+  GdkRGBA *color;
 
   panel_return_if_fail (XFCE_IS_PANEL_PLUGIN_PROVIDER (widget));
   panel_return_if_fail (PANEL_IS_BASE_WINDOW (user_data));
 
   /* send null if the style is not a bg color */
-  color = window->background_style == PANEL_BG_STYLE_COLOR ? window->background_rgba : NULL;
+  color = priv->background_style == PANEL_BG_STYLE_COLOR ? priv->background_rgba : NULL;
   if (PANEL_IS_PLUGIN_EXTERNAL (widget))
     panel_plugin_external_set_background_color (PANEL_PLUGIN_EXTERNAL (widget), color);
 }
@@ -780,7 +804,7 @@ panel_base_window_set_plugin_background_image (GtkWidget *widget,
 
   if (PANEL_IS_PLUGIN_EXTERNAL (widget))
     panel_plugin_external_set_background_image (PANEL_PLUGIN_EXTERNAL (widget),
-        PANEL_BASE_WINDOW (user_data)->background_image);
+                                                get_instance_private (user_data)->background_image);
 }
 
 
@@ -789,7 +813,7 @@ void
 panel_base_window_set_borders (PanelBaseWindow *window,
                                PanelBorders     borders)
 {
-  PanelBaseWindowPrivate *priv = window->priv;
+  PanelBaseWindowPrivate *priv = get_instance_private (window);
 
   panel_return_if_fail (PANEL_IS_BASE_WINDOW (window));
 
@@ -798,7 +822,7 @@ panel_base_window_set_borders (PanelBaseWindow *window,
       priv->borders = borders;
       gtk_widget_queue_resize (GTK_WIDGET (window));
       /* Re-draw the borders if system colors are being used */
-      if (window->background_style == PANEL_BG_STYLE_NONE)
+      if (priv->background_style == PANEL_BG_STYLE_NONE)
         panel_base_window_reset_background_css (window);
     }
 }
@@ -808,7 +832,7 @@ panel_base_window_set_borders (PanelBaseWindow *window,
 PanelBorders
 panel_base_window_get_borders (PanelBaseWindow *window)
 {
-  PanelBaseWindowPrivate *priv = window->priv;
+  PanelBaseWindowPrivate *priv = get_instance_private (window);
 
   panel_return_val_if_fail (PANEL_IS_BASE_WINDOW (window), PANEL_BORDER_NONE);
 
@@ -816,7 +840,7 @@ panel_base_window_get_borders (PanelBaseWindow *window)
   if (priv->active_timeout_id != 0)
     return PANEL_BORDER_TOP | PANEL_BORDER_BOTTOM
            | PANEL_BORDER_LEFT | PANEL_BORDER_RIGHT;
-  else if (window->background_style != PANEL_BG_STYLE_NONE)
+  else if (priv->background_style != PANEL_BG_STYLE_NONE)
     return PANEL_BORDER_NONE;
 
   return priv->borders;
@@ -828,16 +852,20 @@ void
 panel_base_window_opacity_enter (PanelBaseWindow *window,
                                  gboolean         enter)
 {
-  if (! window->is_composited)
+  PanelBaseWindowPrivate *priv = get_instance_private (window);
+
+  panel_return_if_fail (PANEL_IS_BASE_WINDOW (window));
+
+  if (! priv->is_composited)
     return;
 
-  window->opacity_is_enter = enter;
-  if (window->leave_opacity == window->enter_opacity)
+  priv->opacity_is_enter = enter;
+  if (priv->leave_opacity == priv->enter_opacity)
     return;
 
   if (enter)
     {
-      gtk_widget_set_opacity (GTK_WIDGET (window), window->enter_opacity);
+      gtk_widget_set_opacity (GTK_WIDGET (window), priv->enter_opacity);
       panel_base_window_set_plugin_data (window, panel_base_window_set_plugin_enter_opacity);
     }
   else
@@ -846,7 +874,57 @@ panel_base_window_opacity_enter (PanelBaseWindow *window,
       if (gtk_layer_is_supported () && ! panel_window_pointer_is_outside (PANEL_WINDOW (window)))
         return;
 
-      gtk_widget_set_opacity (GTK_WIDGET (window), window->leave_opacity);
+      gtk_widget_set_opacity (GTK_WIDGET (window), priv->leave_opacity);
       panel_base_window_set_plugin_data (window, panel_base_window_set_plugin_leave_opacity);
     }
 }
+
+
+
+gboolean
+panel_base_window_opacity_is_enter (PanelBaseWindow *window)
+{
+  panel_return_val_if_fail (PANEL_IS_BASE_WINDOW (window), FALSE);
+
+  return get_instance_private (window)->opacity_is_enter;
+}
+
+
+
+gboolean
+panel_base_window_is_composited (PanelBaseWindow *window)
+{
+  panel_return_val_if_fail (PANEL_IS_BASE_WINDOW (window), FALSE);
+
+  return get_instance_private (window)->is_composited;
+}
+
+
+
+PanelBgStyle
+panel_base_window_get_background_style (PanelBaseWindow *window)
+{
+  panel_return_val_if_fail (PANEL_IS_BASE_WINDOW (window), PANEL_BG_STYLE_NONE);
+
+  return get_instance_private (window)->background_style;
+}
+
+
+
+GdkRGBA *
+panel_base_window_get_background_rgba (PanelBaseWindow *window)
+{
+  panel_return_val_if_fail (PANEL_IS_BASE_WINDOW (window), NULL);
+
+  return get_instance_private (window)->background_rgba;
+}
+
+
+
+gchar *
+panel_base_window_get_background_image (PanelBaseWindow *window)
+{
+  panel_return_val_if_fail (PANEL_IS_BASE_WINDOW (window), NULL);
+
+  return get_instance_private (window)->background_image;
+}
