@@ -55,11 +55,6 @@ static void      panel_module_plugin_destroyed (gpointer          user_data,
 
 
 
-struct _PanelModuleClass
-{
-  GTypeModuleClass __parent__;
-};
-
 enum _PanelModuleUnique
 {
   UNIQUE_FALSE,
@@ -105,7 +100,7 @@ static GQuark module_quark = 0;
 
 
 
-G_DEFINE_TYPE (PanelModule, panel_module, G_TYPE_TYPE_MODULE)
+G_DEFINE_FINAL_TYPE (PanelModule, panel_module, G_TYPE_TYPE_MODULE)
 
 
 
