@@ -27,17 +27,8 @@
 
 G_BEGIN_DECLS
 
-typedef struct _PanelPluginExternalClass   PanelPluginExternalClass;
-typedef struct _PanelPluginExternal        PanelPluginExternal;
-typedef struct _PanelPluginExternalPrivate PanelPluginExternalPrivate;
-
-#define PANEL_TYPE_PLUGIN_EXTERNAL            (panel_plugin_external_get_type ())
-#define PANEL_PLUGIN_EXTERNAL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), PANEL_TYPE_PLUGIN_EXTERNAL, PanelPluginExternal))
-#define PANEL_PLUGIN_EXTERNAL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), PANEL_TYPE_PLUGIN_EXTERNAL, PanelPluginExternalClass))
-#define PANEL_IS_PLUGIN_EXTERNAL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PANEL_TYPE_PLUGIN_EXTERNAL))
-#define PANEL_IS_PLUGIN_EXTERNAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PANEL_TYPE_PLUGIN_EXTERNAL))
-#define PANEL_PLUGIN_EXTERNAL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), PANEL_TYPE_PLUGIN_EXTERNAL, PanelPluginExternalClass))
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (PanelPluginExternal, g_object_unref)
+#define PANEL_TYPE_PLUGIN_EXTERNAL (panel_plugin_external_get_type ())
+G_DECLARE_DERIVABLE_TYPE (PanelPluginExternal, panel_plugin_external, PANEL, PLUGIN_EXTERNAL, GtkBox)
 
 struct _PanelPluginExternalClass
 {
@@ -57,6 +48,11 @@ struct _PanelPluginExternalClass
                                       const GValue         *value,
                                       guint                *handle);
 
+  /* some info received on plugin startup by the
+   * implementations of the abstract object */
+  gboolean   (*get_show_configure)   (PanelPluginExternal  *external);
+  gboolean   (*get_show_about)       (PanelPluginExternal  *external);
+
   /* X11 only */
   void       (*set_background_color) (PanelPluginExternal  *external,
                                       const GdkRGBA        *color);
@@ -69,22 +65,6 @@ struct _PanelPluginExternalClass
   gboolean   (*pointer_is_outside)   (PanelPluginExternal  *external);
 };
 
-struct _PanelPluginExternal
-{
-  GtkBox __parent__;
-
-  PanelPluginExternalPrivate *priv;
-
-  PanelModule                *module;
-
-  gint                        unique_id;
-
-  /* some info received on plugin startup by the
-   * implementations of the abstract object */
-  guint                       show_configure : 1;
-  guint                       show_about : 1;
-};
-
 typedef struct
 {
   XfcePanelPluginProviderPropType type;
@@ -92,10 +72,6 @@ typedef struct
 }
 PluginProperty;
 
-
-
-GType        panel_plugin_external_get_type             (void) G_GNUC_CONST;
-
 void         panel_plugin_external_queue_add            (PanelPluginExternal              *external,
                                                          XfcePanelPluginProviderPropType   type,
                                                          const GValue                     *value);
@@ -119,6 +95,8 @@ void         panel_plugin_external_set_geometry         (PanelPluginExternal
 
 gboolean     panel_plugin_external_pointer_is_outside   (PanelPluginExternal              *external);
 
+gboolean     panel_plugin_external_get_embedded         (PanelPluginExternal              *external);
+
 void         panel_plugin_external_set_embedded         (PanelPluginExternal              *external,
                                                          gboolean                          embedded);
 
