@@ -22,12 +22,8 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <libxfce4panel/libxfce4panel.h>
-#include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
 
-#include <gio/gio.h>
-
 #include <common/panel-private.h>
 #include <common/panel-xfconf.h>
 #include <common/panel-utils.h>
@@ -38,7 +34,6 @@
 
 
 #define DEFAULT_TITLE    _("Session Menu")
-#define DEFAULT_ICON_SIZE (16)
 #define DEFAULT_TIMEOUT   (30)
 
 
@@ -101,11 +96,6 @@ enum
   COLUMN_TYPE
 };
 
-struct _ActionsPluginClass
-{
-  XfcePanelPluginClass __parent__;
-};
-
 struct _ActionsPlugin
 {
   XfcePanelPlugin __parent__;
@@ -342,7 +332,7 @@ actions_plugin_get_property (GObject    *object,
                              GValue     *value,
                              GParamSpec *pspec)
 {
-  ActionsPlugin *plugin = XFCE_ACTIONS_PLUGIN (object);
+  ActionsPlugin *plugin = ACTIONS_PLUGIN (object);
 
   switch (prop_id)
     {
@@ -381,7 +371,7 @@ actions_plugin_set_property (GObject      *object,
                              const GValue *value,
                              GParamSpec   *pspec)
 {
-  ActionsPlugin *plugin = XFCE_ACTIONS_PLUGIN (object);
+  ActionsPlugin *plugin = ACTIONS_PLUGIN (object);
 
   switch (prop_id)
     {
@@ -424,7 +414,7 @@ actions_plugin_set_property (GObject      *object,
 static void
 actions_plugin_construct (XfcePanelPlugin *panel_plugin)
 {
-  ActionsPlugin       *plugin = XFCE_ACTIONS_PLUGIN (panel_plugin);
+  ActionsPlugin       *plugin = ACTIONS_PLUGIN (panel_plugin);
   const PanelProperty  properties[] =
   {
     { "items", G_TYPE_PTR_ARRAY },
@@ -455,7 +445,7 @@ actions_plugin_construct (XfcePanelPlugin *panel_plugin)
 static void
 actions_plugin_free_data (XfcePanelPlugin *panel_plugin)
 {
-  ActionsPlugin *plugin = XFCE_ACTIONS_PLUGIN (panel_plugin);
+  ActionsPlugin *plugin = ACTIONS_PLUGIN (panel_plugin);
 
   if (plugin->pack_idle_id != 0)
     g_source_remove (plugin->pack_idle_id);
@@ -473,7 +463,7 @@ static gboolean
 actions_plugin_size_changed (XfcePanelPlugin *panel_plugin,
                              gint             size)
 {
-  ActionsPlugin *plugin = XFCE_ACTIONS_PLUGIN (panel_plugin);
+  ActionsPlugin *plugin = ACTIONS_PLUGIN (panel_plugin);
   GtkWidget     *box;
   GList         *children, *li;
   gint           max_size;
@@ -512,7 +502,7 @@ actions_plugin_size_changed (XfcePanelPlugin *panel_plugin,
 static gboolean
 actions_plugin_configure_store (gpointer data)
 {
-  ActionsPlugin *plugin = XFCE_ACTIONS_PLUGIN (data);
+  ActionsPlugin *plugin = ACTIONS_PLUGIN (data);
   GtkTreeModel  *model;
   GtkTreeIter    iter;
   GPtrArray     *array;
@@ -575,7 +565,7 @@ actions_plugin_configure_visible_toggled (GtkCellRendererToggle *renderer,
   gboolean      visible;
   GtkTreeModel *model;
 
-  panel_return_if_fail (XFCE_IS_ACTIONS_PLUGIN (plugin));
+  panel_return_if_fail (ACTIONS_IS_PLUGIN (plugin));
 
   model = g_object_get_data (G_OBJECT (plugin), "items-store");
   panel_return_if_fail (GTK_IS_LIST_STORE (model));
@@ -622,7 +612,7 @@ actions_plugin_combo_title_changed_cb (GtkWidget *widget,
 static void
 actions_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
 {
-  ActionsPlugin *plugin = XFCE_ACTIONS_PLUGIN (panel_plugin);
+  ActionsPlugin *plugin = ACTIONS_PLUGIN (panel_plugin);
   GtkBuilder    *builder;
   GObject       *dialog;
   GObject       *object;
@@ -638,11 +628,10 @@ actions_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
   gchar         *sep_str;
   const gchar   *display_name;
 
-  panel_return_if_fail (XFCE_IS_ACTIONS_PLUGIN (plugin));
+  panel_return_if_fail (ACTIONS_IS_PLUGIN (plugin));
   panel_return_if_fail (plugin->items != NULL);
 
   /* setup the dialog */
-  PANEL_UTILS_LINK_4UI
   builder = panel_utils_builder_new (panel_plugin, actions_dialog_ui,
                                      actions_dialog_ui_length, &dialog);
   if (G_UNLIKELY (builder == NULL))
@@ -759,7 +748,7 @@ static void
 actions_plugin_mode_changed (XfcePanelPlugin     *panel_plugin,
                              XfcePanelPluginMode  mode)
 {
-  actions_plugin_pack (XFCE_ACTIONS_PLUGIN (panel_plugin));
+  actions_plugin_pack (ACTIONS_PLUGIN (panel_plugin));
 }
 
 
@@ -768,7 +757,7 @@ static void
 actions_plugin_nrows_changed (XfcePanelPlugin *panel_plugin,
                               guint            rows)
 {
-  actions_plugin_pack (XFCE_ACTIONS_PLUGIN (panel_plugin));
+  actions_plugin_pack (ACTIONS_PLUGIN (panel_plugin));
 }
 
 
@@ -1214,7 +1203,7 @@ actions_plugin_action_menu_item (ActionsPlugin *plugin,
 static gboolean
 actions_plugin_pack_idle (gpointer data)
 {
-  ActionsPlugin       *plugin = XFCE_ACTIONS_PLUGIN (data);
+  ActionsPlugin       *plugin = ACTIONS_PLUGIN (data);
   GtkWidget           *label;
   GtkWidget           *button;
   GtkWidget           *widget;
@@ -1377,7 +1366,7 @@ actions_plugin_pack_idle (gpointer data)
 static void
 actions_plugin_pack_idle_destoyed (gpointer data)
 {
-  XFCE_ACTIONS_PLUGIN (data)->pack_idle_id = 0;
+  ACTIONS_PLUGIN (data)->pack_idle_id = 0;
 }
 
 
@@ -1435,7 +1424,7 @@ actions_plugin_menu_deactivate (GtkWidget     *menu,
 {
   GtkWidget *button;
 
-  panel_return_if_fail (XFCE_IS_ACTIONS_PLUGIN (plugin));
+  panel_return_if_fail (ACTIONS_IS_PLUGIN (plugin));
   panel_return_if_fail (GTK_IS_MENU (menu));
 
   /* button is NULL when we popup the menu under the cursor position */
@@ -1457,7 +1446,7 @@ actions_plugin_menu (GtkWidget     *button,
   ActionType    type;
   ActionType    allowed_types;
 
-  panel_return_if_fail (XFCE_IS_ACTIONS_PLUGIN (plugin));
+  panel_return_if_fail (ACTIONS_IS_PLUGIN (plugin));
   panel_return_if_fail (button != NULL);
 
   /* do not popup the menu if the button is being toggled off */
