@@ -24,14 +24,11 @@
 #include <string.h>
 #endif
 
-#include <gio/gio.h>
-#include <libxfce4util/libxfce4util.h>
+#include <gtk/gtk.h>
 #include <libxfce4ui/libxfce4ui.h>
-#include <garcon/garcon.h>
 #include <garcon-gtk/garcon-gtk.h>
 #include <xfconf/xfconf.h>
 
-#include <libxfce4panel/libxfce4panel.h>
 #include <common/panel-private.h>
 #include <common/panel-xfconf.h>
 #include <common/panel-utils.h>
@@ -73,8 +70,6 @@ static void               launcher_plugin_screen_position_changed       (XfcePan
                                                                          XfceScreenPosition    position);
 static LauncherArrowType  launcher_plugin_default_arrow_type            (LauncherPlugin       *plugin);
 static void               launcher_plugin_pack_widgets                  (LauncherPlugin       *plugin);
-static cairo_surface_t   *launcher_plugin_tooltip_icon                  (GtkWidget            *widget,
-                                                                         const gchar          *icon_name);
 static void               launcher_plugin_tooltip_icon_invalidate       (GObject              *object);
 static void               launcher_plugin_icon_invalidate               (LauncherPlugin       *plugin);
 static void               launcher_plugin_menu_deactivate               (GtkWidget            *menu,
@@ -173,11 +168,6 @@ static void               launcher_plugin_uri_list_free                 (GSList
 
 
 
-struct _LauncherPluginClass
-{
-  XfcePanelPluginClass __parent__;
-};
-
 struct _LauncherPlugin
 {
   XfcePanelPlugin __parent__;
@@ -368,8 +358,6 @@ launcher_plugin_init (LauncherPlugin *plugin)
   /* invalidate tooltip icon when needed */
   plugin->theme_change_id = g_signal_connect_swapped (gtk_icon_theme_get_default (), "changed",
       G_CALLBACK (launcher_plugin_tooltip_icon_invalidate), plugin->button);
-  g_signal_connect (plugin->button, "notify::scale-factor",
-      G_CALLBACK (launcher_plugin_tooltip_icon_invalidate), NULL);
   g_signal_connect (plugin, "notify::scale-factor",
       G_CALLBACK (launcher_plugin_icon_invalidate), NULL);
   g_signal_connect (plugin, "notify::scale-factor",
@@ -435,7 +423,7 @@ launcher_plugin_get_property (GObject    *object,
                               GValue     *value,
                               GParamSpec *pspec)
 {
-  LauncherPlugin *plugin = XFCE_LAUNCHER_PLUGIN (object);
+  LauncherPlugin *plugin = LAUNCHER_PLUGIN (object);
   GPtrArray      *array;
   GValue         *tmp;
   GSList         *li;
@@ -493,7 +481,7 @@ launcher_plugin_item_changed (GarconMenuItem *item,
   GSList *li;
 
   panel_return_if_fail (GARCON_IS_MENU_ITEM (item));
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   /* find the item */
   li = g_slist_find (plugin->items, item);
@@ -569,7 +557,7 @@ launcher_plugin_item_load (LauncherPlugin *plugin,
   GarconMenuItem *item = NULL;
   GError         *error = NULL;
 
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), NULL);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), NULL);
   panel_return_val_if_fail (str != NULL, NULL);
   panel_return_val_if_fail (G_IS_FILE (plugin->config_directory), NULL);
 
@@ -720,7 +708,7 @@ launcher_plugin_items_load (LauncherPlugin *plugin,
   gboolean        items_modified = FALSE;
   gboolean        location_changed;
 
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
   panel_return_if_fail (array != NULL);
 
   for (i = 0; i < array->len; i++)
@@ -807,7 +795,7 @@ launcher_plugin_set_property (GObject      *object,
                               const GValue *value,
                               GParamSpec   *pspec)
 {
-  LauncherPlugin *plugin = XFCE_LAUNCHER_PLUGIN (object);
+  LauncherPlugin *plugin = LAUNCHER_PLUGIN (object);
   GPtrArray      *array;
 
   panel_return_if_fail (G_IS_FILE (plugin->config_directory));
@@ -913,7 +901,7 @@ launcher_plugin_file_changed (GFileMonitor      *monitor,
   gboolean        exists;
   gboolean        update_plugin = FALSE;
 
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
   panel_return_if_fail (plugin->config_monitor == monitor);
 
   /* waited until all events are proccessed */
@@ -992,7 +980,7 @@ launcher_plugin_file_changed (GFileMonitor      *monitor,
 static void
 launcher_plugin_construct (XfcePanelPlugin *panel_plugin)
 {
-  LauncherPlugin      *plugin = XFCE_LAUNCHER_PLUGIN (panel_plugin);
+  LauncherPlugin      *plugin = LAUNCHER_PLUGIN (panel_plugin);
   const gchar * const *uris;
   guint                i;
   GPtrArray           *array;
@@ -1082,7 +1070,7 @@ launcher_plugin_construct (XfcePanelPlugin *panel_plugin)
 static void
 launcher_plugin_free_data (XfcePanelPlugin *panel_plugin)
 {
-  LauncherPlugin *plugin = XFCE_LAUNCHER_PLUGIN (panel_plugin);
+  LauncherPlugin *plugin = LAUNCHER_PLUGIN (panel_plugin);
   GtkIconTheme   *icon_theme;
 
   /* stop monitoring */
@@ -1125,7 +1113,7 @@ launcher_plugin_free_data (XfcePanelPlugin *panel_plugin)
 static void
 launcher_plugin_removed (XfcePanelPlugin *panel_plugin)
 {
-  LauncherPlugin *plugin = XFCE_LAUNCHER_PLUGIN (panel_plugin);
+  LauncherPlugin *plugin = LAUNCHER_PLUGIN (panel_plugin);
   GError         *error = NULL;
 
   panel_return_if_fail (G_IS_FILE (plugin->config_directory));
@@ -1161,7 +1149,7 @@ launcher_plugin_remote_event (XfcePanelPlugin *panel_plugin,
                               const gchar     *name,
                               const GValue    *value)
 {
-  LauncherPlugin *plugin = XFCE_LAUNCHER_PLUGIN (panel_plugin);
+  LauncherPlugin *plugin = LAUNCHER_PLUGIN (panel_plugin);
 
   panel_return_val_if_fail (value == NULL || G_IS_VALUE (value), FALSE);
 
@@ -1191,7 +1179,7 @@ launcher_plugin_remote_event (XfcePanelPlugin *panel_plugin,
 static void
 launcher_plugin_save_delayed_timeout_destroyed (gpointer user_data)
 {
-  XFCE_LAUNCHER_PLUGIN (user_data)->save_timeout_id = 0;
+  LAUNCHER_PLUGIN (user_data)->save_timeout_id = 0;
 }
 
 
@@ -1225,10 +1213,10 @@ launcher_plugin_mode_changed (XfcePanelPlugin    *panel_plugin,
                               XfcePanelPluginMode mode)
 {
   /* update label orientation */
-  launcher_plugin_button_update (XFCE_LAUNCHER_PLUGIN (panel_plugin));
+  launcher_plugin_button_update (LAUNCHER_PLUGIN (panel_plugin));
 
   /* update the widget order */
-  launcher_plugin_pack_widgets (XFCE_LAUNCHER_PLUGIN (panel_plugin));
+  launcher_plugin_pack_widgets (LAUNCHER_PLUGIN (panel_plugin));
 
   /* update the arrow button */
   launcher_plugin_screen_position_changed (panel_plugin,
@@ -1245,7 +1233,7 @@ static gboolean
 launcher_plugin_size_changed (XfcePanelPlugin *panel_plugin,
                               gint             size)
 {
-  LauncherPlugin    *plugin = XFCE_LAUNCHER_PLUGIN (panel_plugin);
+  LauncherPlugin    *plugin = LAUNCHER_PLUGIN (panel_plugin);
   gint               p_width, p_height;
   gint               a_width, a_height;
   gboolean           horizontal;
@@ -1341,7 +1329,7 @@ static void
 launcher_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
 {
   /* run the configure dialog */
-  launcher_dialog_show (XFCE_LAUNCHER_PLUGIN (panel_plugin));
+  launcher_dialog_show (LAUNCHER_PLUGIN (panel_plugin));
 }
 
 
@@ -1350,7 +1338,7 @@ static void
 launcher_plugin_screen_position_changed (XfcePanelPlugin    *panel_plugin,
                                          XfceScreenPosition  position)
 {
-  LauncherPlugin *plugin = XFCE_LAUNCHER_PLUGIN (panel_plugin);
+  LauncherPlugin *plugin = LAUNCHER_PLUGIN (panel_plugin);
 
   /* set the new arrow direction */
   xfce_arrow_button_set_arrow_type (XFCE_ARROW_BUTTON (plugin->arrow),
@@ -1368,7 +1356,7 @@ launcher_plugin_default_arrow_type (LauncherPlugin *plugin)
   LauncherArrowType pos = plugin->arrow_position;
   gboolean          rtl;
 
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), LAUNCHER_ARROW_NORTH);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), LAUNCHER_ARROW_NORTH);
 
   if (pos == LAUNCHER_ARROW_DEFAULT)
     {
@@ -1392,7 +1380,7 @@ launcher_plugin_pack_widgets (LauncherPlugin *plugin)
 {
   LauncherArrowType pos;
 
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   /* leave when the arrow button is not visible */
   if (!gtk_widget_get_visible (plugin->arrow)
@@ -1416,32 +1404,24 @@ launcher_plugin_pack_widgets (LauncherPlugin *plugin)
 
 
 
-cairo_surface_t *
-launcher_plugin_tooltip_icon (GtkWidget *widget,
-                              const gchar *icon_name)
+GIcon *
+launcher_plugin_tooltip_icon (const gchar *icon_name)
 {
-  cairo_surface_t *surface = NULL;
-  GdkPixbuf *pixbuf;
-  gint scale_factor, size;
+  GIcon *icon;
 
   if (xfce_str_is_empty (icon_name))
     return NULL;
 
-  scale_factor = gtk_widget_get_scale_factor (widget);
-  size = scale_factor * 32;
   if (G_UNLIKELY (g_path_is_absolute (icon_name)))
-    pixbuf = gdk_pixbuf_new_from_file_at_scale (icon_name, size, size, TRUE, NULL);
-  else
-    pixbuf = gtk_icon_theme_load_icon_for_scale (gtk_icon_theme_get_default (), icon_name, 32,
-                                                 scale_factor, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
-
-  if (pixbuf != NULL)
     {
-      surface = gdk_cairo_surface_create_from_pixbuf (pixbuf, scale_factor, NULL);
-      g_object_unref (pixbuf);
+      GFile *file = g_file_new_for_path (icon_name);
+      icon = g_file_icon_new (file);
+      g_object_unref (file);
     }
+  else
+    icon = g_themed_icon_new (icon_name);
 
-  return surface;
+  return icon;
 }
 
 
@@ -1450,7 +1430,7 @@ static void
 launcher_plugin_menu_deactivate (GtkWidget      *menu,
                                  LauncherPlugin *plugin)
 {
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
   panel_return_if_fail (plugin->menu == menu);
 
   /* deactivate the arrow button */
@@ -1499,7 +1479,7 @@ launcher_plugin_menu_item_activate (GtkMenuItem      *widget,
 
   /* get the plugin */
   plugin = g_object_get_qdata (G_OBJECT (widget), launcher_plugin_quark);
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   /* move the item to the first position if enabled */
   if (G_UNLIKELY (plugin->move_first))
@@ -1534,7 +1514,7 @@ launcher_plugin_menu_item_drag_data_received (GtkWidget          *widget,
 
   /* get the plugin */
   plugin = g_object_get_qdata (G_OBJECT (widget), launcher_plugin_quark);
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   /* extract the uris from the selection data */
   uri_list = launcher_plugin_uri_list_extract (data);
@@ -1581,7 +1561,7 @@ launcher_plugin_menu_construct (LauncherPlugin *plugin)
   GSList         *li;
   gint            icon_size;
 
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
   panel_return_if_fail (plugin->menu == NULL);
 
   icon_size = xfce_panel_plugin_get_icon_size (XFCE_PANEL_PLUGIN (plugin));
@@ -1634,8 +1614,6 @@ launcher_plugin_menu_construct (LauncherPlugin *plugin)
           /* invalidate tooltip icon when needed */
           g_signal_connect_object (gtk_icon_theme_get_default (), "changed",
               G_CALLBACK (launcher_plugin_tooltip_icon_invalidate), mi, G_CONNECT_SWAPPED);
-          g_signal_connect (mi, "notify::scale-factor",
-              G_CALLBACK (launcher_plugin_tooltip_icon_invalidate), NULL);
         }
 
       /* depending on the menu position we prepend or append */
@@ -1684,7 +1662,7 @@ launcher_plugin_menu_construct (LauncherPlugin *plugin)
 static void
 launcher_plugin_menu_popup_destroyed (gpointer user_data)
 {
-   XFCE_LAUNCHER_PLUGIN (user_data)->menu_timeout_id = 0;
+   LAUNCHER_PLUGIN (user_data)->menu_timeout_id = 0;
 }
 
 
@@ -1692,10 +1670,11 @@ launcher_plugin_menu_popup_destroyed (gpointer user_data)
 static gboolean
 launcher_plugin_menu_popup (gpointer user_data)
 {
-  LauncherPlugin *plugin = XFCE_LAUNCHER_PLUGIN (user_data);
+  LauncherPlugin *plugin = LAUNCHER_PLUGIN (user_data);
   gint            x, y;
+  GdkEventButton *event = NULL;
 
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), FALSE);
 
   /* construct the menu if needed */
   if (plugin->menu == NULL)
@@ -1707,12 +1686,21 @@ launcher_plugin_menu_popup (gpointer user_data)
   else
     gtk_widget_set_state_flags (GTK_WIDGET (plugin->button), GTK_STATE_FLAG_CHECKED, TRUE);
 
+  /* avoid warning when there is no current event */
+  if (gtk_get_current_event () == NULL)
+    {
+      event = g_slice_new0 (GdkEventButton);
+      event->type = GDK_BUTTON_PRESS;
+      event->window = gdk_get_default_root_window ();
+    }
+
   /* popup the menu */
   xfce_panel_plugin_popup_menu (XFCE_PANEL_PLUGIN (plugin), GTK_MENU (plugin->menu),
-                                plugin->button, NULL);
+                                plugin->button, (GdkEvent *) event);
 
-  /* fallback to manual positioning, this is used with
-   * drag motion over the arrow button */
+  /* fallback to manual positioning, this is used with drag motion over the arrow button
+   * from e.g. Thunar, not from the app menu, where showing the menu does not work for
+   * some other reason: see https://gitlab.xfce.org/xfce/xfce4-panel/-/issues/205 */
   if (!gtk_widget_get_visible (plugin->menu))
     {
       /* make sure the size is allocated */
@@ -1737,7 +1725,7 @@ launcher_plugin_menu_popup (gpointer user_data)
 static void
 launcher_plugin_menu_destroy (LauncherPlugin *plugin)
 {
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   /* stop pending timeout */
   if (plugin->menu_timeout_id != 0)
@@ -1772,7 +1760,7 @@ launcher_plugin_button_update (LauncherPlugin *plugin)
   XfcePanelPluginMode  mode;
   gint                 icon_size;
 
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   /* invalidate cached icons */
   launcher_plugin_tooltip_icon_invalidate (G_OBJECT (plugin->button));
@@ -1853,11 +1841,11 @@ launcher_plugin_button_update (LauncherPlugin *plugin)
 static void
 launcher_plugin_add_desktop_actions (GtkWidget *widget, gpointer user_data)
 {
-  LauncherPlugin *plugin = XFCE_LAUNCHER_PLUGIN (user_data);
+  LauncherPlugin *plugin = LAUNCHER_PLUGIN (user_data);
 
   panel_return_if_fail (GTK_IS_WIDGET (widget));
   panel_return_if_fail (GTK_IS_MENU (plugin->action_menu));
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   /* Pack the action menu item into the plugin's context menu */
   g_object_ref (widget);
@@ -1874,17 +1862,9 @@ launcher_plugin_button_update_action_menu (LauncherPlugin *plugin)
   GarconMenuItem *item = NULL;
   GList          *list;
 
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
   panel_return_if_fail (plugin->menu == NULL);
 
-  /* If there are >1 items in the launcher don't show the action menu */
-  if (LIST_HAS_TWO_OR_MORE_ENTRIES (plugin->items))
-    {
-      xfce_panel_plugin_menu_destroy (XFCE_PANEL_PLUGIN (plugin));
-      plugin->action_menu = NULL;
-      return;
-    }
-
   if (G_LIKELY (plugin->items != NULL))
     item = GARCON_MENU_ITEM (plugin->items->data);
 
@@ -1929,7 +1909,7 @@ launcher_plugin_button_press_event (GtkWidget      *button,
 {
   guint modifiers;
 
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), FALSE);
 
   /* do nothing on anything else then a single click */
   if (event->type != GDK_BUTTON_PRESS)
@@ -1971,7 +1951,7 @@ launcher_plugin_button_release_event (GtkWidget      *button,
   GarconMenuItem *item;
   GdkScreen      *screen;
 
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), FALSE);
 
   /* remove a delayed popup timeout */
   if (plugin->menu_timeout_id != 0)
@@ -2012,7 +1992,7 @@ launcher_plugin_button_query_tooltip (GtkWidget      *widget,
                                       GtkTooltip     *tooltip,
                                       LauncherPlugin *plugin)
 {
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), FALSE);
   panel_return_val_if_fail (!plugin->disable_tooltips, FALSE);
 
   /* check if we show tooltips */
@@ -2038,7 +2018,7 @@ launcher_plugin_button_drag_data_received (GtkWidget        *widget,
 {
   GSList *uri_list;
 
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   /* leave when there are not items or the arrow is internal */
   if (ARROW_INSIDE_BUTTON (plugin) || plugin->items == NULL)
@@ -2101,7 +2081,7 @@ launcher_plugin_button_drag_motion (GtkWidget      *widget,
                                     guint           drag_time,
                                     LauncherPlugin *plugin)
 {
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), FALSE);
 
   if (launcher_plugin_supported_drop (context, widget) == GDK_NONE)
     return FALSE;
@@ -2156,7 +2136,7 @@ launcher_plugin_button_drag_leave (GtkWidget      *widget,
                                    guint           drag_time,
                                    LauncherPlugin *plugin)
 {
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   /* unhighlight the widget or make sure the menu is deactivated */
   if (NO_ARROW_INSIDE_BUTTON (plugin))
@@ -2179,7 +2159,7 @@ launcher_plugin_button_draw (GtkWidget      *widget,
   GtkStyleContext  *ctx;
   GtkBorder         padding;
 
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), FALSE);
 
   /* leave when the arrow is not shown inside the button */
   if (NO_ARROW_INSIDE_BUTTON (plugin))
@@ -2239,7 +2219,7 @@ launcher_plugin_button_draw (GtkWidget      *widget,
 static void
 launcher_plugin_arrow_visibility (LauncherPlugin *plugin)
 {
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   if (plugin->arrow_position != LAUNCHER_ARROW_INTERNAL
        && LIST_HAS_TWO_OR_MORE_ENTRIES (plugin->items))
@@ -2255,7 +2235,7 @@ launcher_plugin_arrow_press_event (GtkWidget      *button,
                                    GdkEventButton *event,
                                    LauncherPlugin *plugin)
 {
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), FALSE);
 
   /* only popup when button 1 is pressed */
   if (event->button == 1 && event->type == GDK_BUTTON_PRESS)
@@ -2278,7 +2258,7 @@ launcher_plugin_arrow_drag_motion (GtkWidget      *widget,
                                    guint           drag_time,
                                    LauncherPlugin *plugin)
 {
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), FALSE);
 
   if (launcher_plugin_supported_drop (context, widget) == GDK_NONE)
     return FALSE;
@@ -2306,19 +2286,26 @@ launcher_plugin_arrow_drag_motion (GtkWidget      *widget,
 static gboolean
 launcher_plugin_arrow_drag_leave_timeout (gpointer user_data)
 {
-  LauncherPlugin *plugin = XFCE_LAUNCHER_PLUGIN (user_data);
+  LauncherPlugin *plugin = LAUNCHER_PLUGIN (user_data);
   gint            pointer_x, pointer_y;
   GtkWidget      *menu = plugin->menu;
   gint            menu_x, menu_y, menu_w, menu_h;
   GdkDevice      *device;
 
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), FALSE);
   panel_return_val_if_fail (menu == NULL || gtk_widget_get_has_window (menu), FALSE);
 
   /* leave when the menu is destroyed */
   if (G_UNLIKELY (plugin->menu == NULL))
     return FALSE;
 
+  /* leave if the menu is already hidden */
+  if (! gtk_widget_get_visible (plugin->menu))
+    {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (plugin->arrow), FALSE);
+      return FALSE;
+    }
+
   device = gdk_seat_get_pointer (gdk_display_get_default_seat (gtk_widget_get_display (menu)));
   if (device == NULL)
     return FALSE;
@@ -2354,7 +2341,7 @@ launcher_plugin_arrow_drag_leave (GtkWidget      *widget,
                                   guint           drag_time,
                                   LauncherPlugin *plugin)
 {
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   if (plugin->menu_timeout_id != 0)
     {
@@ -2401,10 +2388,9 @@ launcher_plugin_item_query_tooltip (GtkWidget      *widget,
                                     GtkTooltip     *tooltip,
                                     GarconMenuItem *item)
 {
-  GtkWidget *box, *label, *image;
   gchar *markup;
   const gchar *name, *comment;
-  cairo_surface_t *surface;
+  GIcon *icon;
 
   panel_return_val_if_fail (GARCON_IS_MENU_ITEM (item), FALSE);
 
@@ -2417,32 +2403,25 @@ launcher_plugin_item_query_tooltip (GtkWidget      *widget,
   if (!xfce_str_is_empty (comment))
     {
       markup = g_markup_printf_escaped ("<b>%s</b>\n%s", name, comment);
-      label = gtk_label_new (markup);
-      gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+      gtk_tooltip_set_markup (tooltip, markup);
       g_free (markup);
     }
   else
     {
-      label = gtk_label_new (name);
+      gtk_tooltip_set_text (tooltip, name);
     }
 
-  surface = g_object_get_data (G_OBJECT (widget), "tooltip-icon");
-  if (G_UNLIKELY (surface == NULL))
+  icon = g_object_get_data (G_OBJECT (widget), "tooltip-icon");
+  if (G_UNLIKELY (icon == NULL))
     {
-      surface = launcher_plugin_tooltip_icon (widget, garcon_menu_item_get_icon_name (item));
-      if (G_LIKELY (surface != NULL))
+      icon = launcher_plugin_tooltip_icon (garcon_menu_item_get_icon_name (item));
+      if (G_LIKELY (icon != NULL))
         {
-          g_object_set_data_full (G_OBJECT (widget), "tooltip-icon", surface,
-                                  (GDestroyNotify) cairo_surface_destroy);
+          g_object_set_data_full (G_OBJECT (widget), "tooltip-icon", icon, g_object_unref);
         }
     }
 
-  image = gtk_image_new_from_surface (surface);
-  box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-  gtk_box_pack_start (GTK_BOX (box), image, TRUE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (box), label, TRUE, FALSE, 0);
-  gtk_widget_show_all (box);
-  gtk_tooltip_set_custom (tooltip, box);
+  gtk_tooltip_set_icon_from_gicon (tooltip, icon, GTK_ICON_SIZE_DND);
 
   return TRUE;
 }
@@ -2672,7 +2651,7 @@ launcher_plugin_uri_list_free (GSList *uri_list)
 GSList *
 launcher_plugin_get_items (LauncherPlugin *plugin)
 {
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), NULL);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), NULL);
 
   /* set extra reference and return a copy of the list */
   g_slist_foreach (plugin->items, (GFunc) (void (*)(void)) g_object_ref, NULL);
@@ -2687,7 +2666,7 @@ launcher_plugin_unique_filename (LauncherPlugin *plugin)
   gchar        *filename, *path;
   static guint  counter = 0;
 
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), NULL);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), NULL);
 
   filename = g_strdup_printf (RELATIVE_CONFIG_PATH G_DIR_SEPARATOR_S "%" G_GINT64_FORMAT "%d.desktop",
                               xfce_panel_plugin_get_name (XFCE_PANEL_PLUGIN (plugin)),
@@ -2789,7 +2768,7 @@ launcher_plugin_item_is_editable (LauncherPlugin *plugin,
   gboolean   editable = FALSE;
   GFileInfo *file_info;
 
-  panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (LAUNCHER_IS_PLUGIN (plugin), FALSE);
   panel_return_val_if_fail (GARCON_IS_MENU_ITEM (item), FALSE);
 
   item_file = garcon_menu_item_get_file (item);
