@@ -34,8 +34,6 @@
 #define pager_plugin_miniature_view_is_supported() FALSE
 #endif
 
-#include <libxfce4panel/libxfce4panel.h>
-#include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
 #include <common/panel-xfconf.h>
 #include <common/panel-utils.h>
@@ -101,11 +99,6 @@ static void     pager_plugin_get_preferred_height_for_width (GtkWidget
 
 
 
-struct _PagerPluginClass
-{
-  XfcePanelPluginClass __parent__;
-};
-
 struct _PagerPlugin
 {
   XfcePanelPlugin __parent__;
@@ -114,6 +107,11 @@ struct _PagerPlugin
 
   XfwScreen     *xfw_screen;
   XfwWorkspaceGroup *workspace_group;
+#ifdef HAVE_LIBWNCK
+#if WNCK_CHECK_VERSION (43, 0, 0)
+  WnckHandle    *wnck_handle;
+#endif
+#endif
 
   /* settings */
   guint          scrolling : 1;
@@ -142,9 +140,7 @@ static GSList *plugin_list = NULL;
 
 
 
-/* define the plugin */
-XFCE_PANEL_DEFINE_PLUGIN_RESIDENT (PagerPlugin, pager_plugin,
-    pager_buttons_register_type)
+XFCE_PANEL_DEFINE_PLUGIN_RESIDENT (PagerPlugin, pager_plugin)
 
 
 
@@ -225,6 +221,11 @@ pager_plugin_init (PagerPlugin *plugin)
   plugin->pager = NULL;
   plugin->sync_idle_id = 0;
   plugin->sync_wait = TRUE;
+#ifdef HAVE_LIBWNCK
+#if WNCK_CHECK_VERSION (43, 0, 0)
+  plugin->wnck_handle = wnck_handle_new (WNCK_CLIENT_TYPE_PAGER);
+#endif
+#endif
 
   master_plugin = pager_plugin_get_master_plugin (plugin);
   if (master_plugin == NULL)
@@ -243,7 +244,7 @@ pager_plugin_get_property (GObject    *object,
                            GValue     *value,
                            GParamSpec *pspec)
 {
-  PagerPlugin *plugin = XFCE_PAGER_PLUGIN (object);
+  PagerPlugin *plugin = PAGER_PLUGIN (object);
 
   switch (prop_id)
     {
@@ -281,7 +282,7 @@ pager_plugin_set_property (GObject      *object,
                            const GValue *value,
                            GParamSpec   *pspec)
 {
-  PagerPlugin *plugin = XFCE_PAGER_PLUGIN (object), *master_plugin;
+  PagerPlugin *plugin = PAGER_PLUGIN (object), *master_plugin;
   guint        rows;
 
   switch (prop_id)
@@ -320,12 +321,12 @@ pager_plugin_set_property (GObject      *object,
             wnck_pager_set_n_rows (WNCK_PAGER (plugin->pager), plugin->rows);
           else
 #endif
-            pager_buttons_set_n_rows (XFCE_PAGER_BUTTONS (plugin->pager), plugin->rows);
+            pager_buttons_set_n_rows (PAGER_BUTTONS (plugin->pager), plugin->rows);
 
           /* set n_rows for other plugins: this will queue a pager re-creation */
           for (GSList *lp = plugin_list; lp != NULL; lp = lp->next)
             if (lp->data != plugin
-                && XFCE_PAGER_PLUGIN (lp->data)->xfw_screen == plugin->xfw_screen)
+                && PAGER_PLUGIN (lp->data)->xfw_screen == plugin->xfw_screen)
               g_object_set (lp->data, "rows", plugin->rows, NULL);
         }
       else
@@ -346,7 +347,7 @@ pager_plugin_set_property (GObject      *object,
 
       if (plugin->pager != NULL
           && !plugin->miniature_view)
-        pager_buttons_set_numbering (XFCE_PAGER_BUTTONS (plugin->pager), plugin->numbering);
+        pager_buttons_set_numbering (PAGER_BUTTONS (plugin->pager), plugin->numbering);
       break;
 
     default:
@@ -399,7 +400,7 @@ static gboolean
 pager_plugin_scroll_event (GtkWidget      *widget,
                            GdkEventScroll *event)
 {
-  PagerPlugin        *plugin = XFCE_PAGER_PLUGIN (widget);
+  PagerPlugin        *plugin = PAGER_PLUGIN (widget);
   XfwWorkspace       *active_ws;
   XfwWorkspace       *new_ws;
   gint                active_n;
@@ -470,7 +471,7 @@ pager_plugin_drag_begin_event (GtkWidget      *widget,
 {
   PagerPlugin *plugin = user_data;
 
-  panel_return_if_fail (XFCE_IS_PAGER_PLUGIN (plugin));
+  panel_return_if_fail (PAGER_IS_PLUGIN (plugin));
   xfce_panel_plugin_block_autohide (XFCE_PANEL_PLUGIN (plugin), TRUE);
 }
 
@@ -483,7 +484,7 @@ pager_plugin_drag_end_event (GtkWidget      *widget,
 {
   PagerPlugin *plugin = user_data;
 
-  panel_return_if_fail (XFCE_IS_PAGER_PLUGIN (plugin));
+  panel_return_if_fail (PAGER_IS_PLUGIN (plugin));
   xfce_panel_plugin_block_autohide (XFCE_PANEL_PLUGIN (plugin), FALSE);
 }
 
@@ -525,7 +526,7 @@ pager_plugin_get_master_plugin (PagerPlugin *plugin)
 {
   /* one master plugin per XfwScreen  */
   for (GSList *lp = plugin_list; lp != NULL; lp = lp->next)
-    if (XFCE_PAGER_PLUGIN (lp->data)->xfw_screen == plugin->xfw_screen)
+    if (PAGER_PLUGIN (lp->data)->xfw_screen == plugin->xfw_screen)
       return lp->data;
 
   return NULL;
@@ -562,7 +563,7 @@ pager_plugin_screen_layout_changed (PagerPlugin *plugin)
   XfcePanelPluginMode mode;
   GtkOrientation      orientation;
 
-  panel_return_if_fail (XFCE_IS_PAGER_PLUGIN (plugin));
+  panel_return_if_fail (PAGER_IS_PLUGIN (plugin));
   panel_return_if_fail (XFW_IS_SCREEN (plugin->xfw_screen));
 
   /* changing workspace layout is delayed in Libwnck code, so we have to give time
@@ -587,9 +588,13 @@ pager_plugin_screen_layout_changed (PagerPlugin *plugin)
     {
       pager_plugin_set_ratio (plugin);
 
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+#if WNCK_CHECK_VERSION (43, 0, 0)
+      /* using a handle allows in particular the pager not to be affected by a possible
+       * change of default wnck icon size in other plugins */
+      plugin->pager = wnck_pager_new_with_handle (plugin->wnck_handle);
+#else
       plugin->pager = wnck_pager_new ();
-G_GNUC_END_IGNORE_DEPRECATIONS
+#endif
       g_signal_connect_after (G_OBJECT (plugin->pager), "drag-begin",
                               G_CALLBACK (pager_plugin_drag_begin_event), plugin);
       g_signal_connect_after (G_OBJECT (plugin->pager), "drag-end",
@@ -609,9 +614,9 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 #endif
     {
       plugin->pager = pager_buttons_new (plugin->xfw_screen);
-      pager_buttons_set_n_rows (XFCE_PAGER_BUTTONS (plugin->pager), plugin->rows);
-      pager_buttons_set_orientation (XFCE_PAGER_BUTTONS (plugin->pager), orientation);
-      pager_buttons_set_numbering (XFCE_PAGER_BUTTONS (plugin->pager), plugin->numbering);
+      pager_buttons_set_n_rows (PAGER_BUTTONS (plugin->pager), plugin->rows);
+      pager_buttons_set_orientation (PAGER_BUTTONS (plugin->pager), orientation);
+      pager_buttons_set_numbering (PAGER_BUTTONS (plugin->pager), plugin->numbering);
       gtk_container_add (GTK_CONTAINER (plugin), plugin->pager);
     }
 
@@ -630,7 +635,7 @@ static void
 pager_plugin_screen_changed (GtkWidget *widget,
                              GdkScreen *previous_screen)
 {
-  PagerPlugin *plugin = XFCE_PAGER_PLUGIN (widget);
+  PagerPlugin *plugin = PAGER_PLUGIN (widget);
   GdkScreen *screen;
   XfwScreen *xfw_screen;
   XfwWorkspaceManager *manager;
@@ -663,7 +668,7 @@ pager_plugin_screen_changed (GtkWidget *widget,
 static void
 pager_plugin_construct (XfcePanelPlugin *panel_plugin)
 {
-  PagerPlugin         *plugin = XFCE_PAGER_PLUGIN (panel_plugin);
+  PagerPlugin         *plugin = PAGER_PLUGIN (panel_plugin);
   GtkWidget           *mi, *image;
   const PanelProperty  properties[] =
   {
@@ -701,11 +706,17 @@ pager_plugin_construct (XfcePanelPlugin *panel_plugin)
 static void
 pager_plugin_free_data (XfcePanelPlugin *panel_plugin)
 {
-  PagerPlugin *plugin = XFCE_PAGER_PLUGIN (panel_plugin);
+  PagerPlugin *plugin = PAGER_PLUGIN (panel_plugin);
 
   g_signal_handlers_disconnect_by_func (G_OBJECT (plugin),
       pager_plugin_screen_changed, NULL);
 
+#ifdef HAVE_LIBWNCK
+#if WNCK_CHECK_VERSION (43, 0, 0)
+  g_object_unref (plugin->wnck_handle);
+#endif
+#endif
+
   plugin_list = g_slist_remove (plugin_list, plugin);
   if (plugin->sync_idle_id != 0)
     g_source_remove (plugin->sync_idle_id);
@@ -731,7 +742,7 @@ static void
 pager_plugin_mode_changed (XfcePanelPlugin     *panel_plugin,
                            XfcePanelPluginMode  mode)
 {
-  PagerPlugin       *plugin = XFCE_PAGER_PLUGIN (panel_plugin);
+  PagerPlugin       *plugin = PAGER_PLUGIN (panel_plugin);
   GtkOrientation     orientation;
 
   if (plugin->pager == NULL)
@@ -746,7 +757,7 @@ pager_plugin_mode_changed (XfcePanelPlugin     *panel_plugin,
     wnck_pager_set_orientation (WNCK_PAGER (plugin->pager), orientation);
   else
 #endif
-    pager_buttons_set_orientation (XFCE_PAGER_BUTTONS (plugin->pager), orientation);
+    pager_buttons_set_orientation (PAGER_BUTTONS (plugin->pager), orientation);
 }
 
 
@@ -823,7 +834,7 @@ static void
 pager_plugin_configure_destroyed (gpointer  data,
                                   GObject  *where_the_object_was)
 {
-  PagerPlugin *plugin = XFCE_PAGER_PLUGIN (data);
+  PagerPlugin *plugin = PAGER_PLUGIN (data);
 
   g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->workspace_group),
                                         pager_plugin_configure_n_workspaces_changed,
@@ -835,14 +846,13 @@ pager_plugin_configure_destroyed (gpointer  data,
 static void
 pager_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
 {
-  PagerPlugin *plugin = XFCE_PAGER_PLUGIN (panel_plugin);
+  PagerPlugin *plugin = PAGER_PLUGIN (panel_plugin);
   GtkBuilder  *builder;
   GObject     *dialog, *object;
 
-  panel_return_if_fail (XFCE_IS_PAGER_PLUGIN (plugin));
+  panel_return_if_fail (PAGER_IS_PLUGIN (plugin));
 
   /* setup the dialog */
-  PANEL_UTILS_LINK_4UI
   builder = panel_utils_builder_new (panel_plugin, pager_dialog_ui,
                                      pager_dialog_ui_length, &dialog);
   if (G_UNLIKELY (builder == NULL))
@@ -910,7 +920,7 @@ pager_plugin_get_preferred_width (GtkWidget *widget,
                                   gint      *minimum_width,
                                   gint      *natural_width)
 {
-  PagerPlugin         *plugin = XFCE_PAGER_PLUGIN (widget);
+  PagerPlugin         *plugin = PAGER_PLUGIN (widget);
   XfcePanelPluginMode  mode;
   gint                 n_workspaces, n_cols;
   gint                 min_width = 0;
@@ -942,7 +952,7 @@ pager_plugin_get_preferred_height (GtkWidget *widget,
                                    gint      *minimum_height,
                                    gint      *natural_height)
 {
-  PagerPlugin         *plugin = XFCE_PAGER_PLUGIN (widget);
+  PagerPlugin         *plugin = PAGER_PLUGIN (widget);
   XfcePanelPluginMode  mode;
   gint                 n_workspaces, n_cols;
   gint                 min_height = 0;
