@@ -121,8 +121,7 @@ wrapper_plug_wayland_window_state_changed (XfwWindow *window,
     gtk_layer_set_layer (GTK_WINDOW (plug), GTK_LAYER_SHELL_LAYER_OVERLAY);
 
   /* to ensure that the layer change is taken into account */
-  gtk_widget_hide (GTK_WIDGET (plug));
-  gtk_widget_show (GTK_WIDGET (plug));
+  panel_utils_widget_remap (GTK_WIDGET (plug));
 }
 
 static void
@@ -352,6 +351,10 @@ static void
 wrapper_plug_wayland_set_geometry (WrapperPlug *plug,
                                    const GdkRectangle *geometry)
 {
+  GdkRectangle monitor_geom;
+  gint old_margin_x = gtk_layer_get_margin (GTK_WINDOW (plug), GTK_LAYER_SHELL_EDGE_LEFT);
+  gint old_margin_y = gtk_layer_get_margin (GTK_WINDOW (plug), GTK_LAYER_SHELL_EDGE_TOP);
+
   WRAPPER_PLUG_WAYLAND (plug)->geometry = *geometry;
 
   /* acts as a lower bound for allocation (see size_allocate() above) */
@@ -359,7 +362,12 @@ wrapper_plug_wayland_set_geometry (WrapperPlug *plug,
 
   gtk_layer_set_margin (GTK_WINDOW (plug), GTK_LAYER_SHELL_EDGE_LEFT, geometry->x);
   gtk_layer_set_margin (GTK_WINDOW (plug), GTK_LAYER_SHELL_EDGE_TOP, geometry->y);
-  panel_utils_wl_surface_commit (GTK_WIDGET (plug));
+
+  /* manual commit needed if plug was off-screen */
+  gdk_monitor_get_geometry (gtk_layer_get_monitor (GTK_WINDOW (plug)), &monitor_geom);
+  if (old_margin_x <= geometry->width || old_margin_x >= monitor_geom.width
+      || old_margin_y <= geometry->height || old_margin_y >= monitor_geom.height)
+    panel_utils_wl_surface_commit (GTK_WIDGET (plug));
 }
 
 
